# coding: utf-8

"""
    message-center-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_message_service.api_client import ApiClient
from dhicn_message_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UserMessageCenterApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_message_type_cancel_mark_post(self, **kwargs):  # noqa: E501
        """取消标记 cancel mark message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_cancel_mark_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_cancel_mark_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_message_type_cancel_mark_post_with_http_info(self, **kwargs):  # noqa: E501
        """取消标记 cancel mark message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_cancel_mark_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_cancel_mark_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/cancel-mark', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_delete_message_post(self, **kwargs):  # noqa: E501
        """删除用户消息 delete message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_delete_message_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_delete_message_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_message_type_delete_message_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除用户消息 delete message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_delete_message_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_delete_message_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/delete-message', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_get_lastest_message_by_type_post(self, **kwargs):  # noqa: E501
        """根据消息类型获取最新的一条未读消息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_lastest_message_by_type_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LastestMessageByMsgTypeInput lastest_message_by_msg_type_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[UserMsgOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_get_lastest_message_by_type_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_message_type_get_lastest_message_by_type_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据消息类型获取最新的一条未读消息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_lastest_message_by_type_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LastestMessageByMsgTypeInput lastest_message_by_msg_type_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[UserMsgOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'lastest_message_by_msg_type_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_get_lastest_message_by_type_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'lastest_message_by_msg_type_input' in local_var_params:
            body_params = local_var_params['lastest_message_by_msg_type_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/get-lastest-message-by-type', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserMsgOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_get_lastest_message_post(self, **kwargs):  # noqa: E501
        """获取最新的一条未读消息 get lastest message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_lastest_message_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetLastestMessageInput get_lastest_message_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserMsgOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_get_lastest_message_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_message_type_get_lastest_message_post_with_http_info(self, **kwargs):  # noqa: E501
        """获取最新的一条未读消息 get lastest message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_lastest_message_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetLastestMessageInput get_lastest_message_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserMsgOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'get_lastest_message_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_get_lastest_message_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_lastest_message_input' in local_var_params:
            body_params = local_var_params['get_lastest_message_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/get-lastest-message', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserMsgOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_get_mark_count_get(self, receiver_user_id, **kwargs):  # noqa: E501
        """获取用户标记消息数量 get user's remark message count  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_mark_count_get(receiver_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str receiver_user_id: 接收人ID  <br>receiver id (required)
        :param str msg_type: 消息类型  <br> message's type 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_get_mark_count_get_with_http_info(receiver_user_id, **kwargs)  # noqa: E501

    def api_v1_message_type_get_mark_count_get_with_http_info(self, receiver_user_id, **kwargs):  # noqa: E501
        """获取用户标记消息数量 get user's remark message count  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_mark_count_get_with_http_info(receiver_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str receiver_user_id: 接收人ID  <br>receiver id (required)
        :param str msg_type: 消息类型  <br> message's type 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(int, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'receiver_user_id',
            'msg_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_get_mark_count_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'receiver_user_id' is set
        if self.api_client.client_side_validation and ('receiver_user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['receiver_user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `receiver_user_id` when calling `api_v1_message_type_get_mark_count_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'receiver_user_id' in local_var_params and local_var_params['receiver_user_id'] is not None:  # noqa: E501
            query_params.append(('ReceiverUserId', local_var_params['receiver_user_id']))  # noqa: E501
        if 'msg_type' in local_var_params and local_var_params['msg_type'] is not None:  # noqa: E501
            query_params.append(('MsgType', local_var_params['msg_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/get-mark-count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_get_message_by_status_get(self, receiver_user_id, **kwargs):  # noqa: E501
        """获取用户消息-已读/未读/标记/全部 get user's message by status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_message_by_status_get(receiver_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str receiver_user_id: 接收人ID  <br>receiver id (required)
        :param int level:
        :param str is_read: 是否已读  <br> whether the message has been read 
        :param str is_mark: 是否已标记  <br> whether the message has been remark 
        :param int page_index:
        :param int page_size:
        :param str key_words:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserMsgOutputPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_get_message_by_status_get_with_http_info(receiver_user_id, **kwargs)  # noqa: E501

    def api_v1_message_type_get_message_by_status_get_with_http_info(self, receiver_user_id, **kwargs):  # noqa: E501
        """获取用户消息-已读/未读/标记/全部 get user's message by status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_message_by_status_get_with_http_info(receiver_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str receiver_user_id: 接收人ID  <br>receiver id (required)
        :param int level:
        :param str is_read: 是否已读  <br> whether the message has been read 
        :param str is_mark: 是否已标记  <br> whether the message has been remark 
        :param int page_index:
        :param int page_size:
        :param str key_words:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserMsgOutputPage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'receiver_user_id',
            'level',
            'is_read',
            'is_mark',
            'page_index',
            'page_size',
            'key_words'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_get_message_by_status_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'receiver_user_id' is set
        if self.api_client.client_side_validation and ('receiver_user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['receiver_user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `receiver_user_id` when calling `api_v1_message_type_get_message_by_status_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'receiver_user_id' in local_var_params and local_var_params['receiver_user_id'] is not None:  # noqa: E501
            query_params.append(('ReceiverUserId', local_var_params['receiver_user_id']))  # noqa: E501
        if 'level' in local_var_params and local_var_params['level'] is not None:  # noqa: E501
            query_params.append(('Level', local_var_params['level']))  # noqa: E501
        if 'is_read' in local_var_params and local_var_params['is_read'] is not None:  # noqa: E501
            query_params.append(('IsRead', local_var_params['is_read']))  # noqa: E501
        if 'is_mark' in local_var_params and local_var_params['is_mark'] is not None:  # noqa: E501
            query_params.append(('IsMark', local_var_params['is_mark']))  # noqa: E501
        if 'page_index' in local_var_params and local_var_params['page_index'] is not None:  # noqa: E501
            query_params.append(('PageIndex', local_var_params['page_index']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('PageSize', local_var_params['page_size']))  # noqa: E501
        if 'key_words' in local_var_params and local_var_params['key_words'] is not None:  # noqa: E501
            query_params.append(('KeyWords', local_var_params['key_words']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/get-message-by-status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserMsgOutputPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_get_unread_count_get(self, receiver_user_id, **kwargs):  # noqa: E501
        """获取用户未读消息数量 get user's unread message count  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_unread_count_get(receiver_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str receiver_user_id: 接收人ID  <br>receiver id (required)
        :param str msg_type: 消息类型  <br> message's type 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_get_unread_count_get_with_http_info(receiver_user_id, **kwargs)  # noqa: E501

    def api_v1_message_type_get_unread_count_get_with_http_info(self, receiver_user_id, **kwargs):  # noqa: E501
        """获取用户未读消息数量 get user's unread message count  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_get_unread_count_get_with_http_info(receiver_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str receiver_user_id: 接收人ID  <br>receiver id (required)
        :param str msg_type: 消息类型  <br> message's type 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(int, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'receiver_user_id',
            'msg_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_get_unread_count_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'receiver_user_id' is set
        if self.api_client.client_side_validation and ('receiver_user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['receiver_user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `receiver_user_id` when calling `api_v1_message_type_get_unread_count_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'receiver_user_id' in local_var_params and local_var_params['receiver_user_id'] is not None:  # noqa: E501
            query_params.append(('ReceiverUserId', local_var_params['receiver_user_id']))  # noqa: E501
        if 'msg_type' in local_var_params and local_var_params['msg_type'] is not None:  # noqa: E501
            query_params.append(('MsgType', local_var_params['msg_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/get-unread-count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_mark_message_post(self, **kwargs):  # noqa: E501
        """指定消息为标记消息 mark message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_mark_message_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_mark_message_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_message_type_mark_message_post_with_http_info(self, **kwargs):  # noqa: E501
        """指定消息为标记消息 mark message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_mark_message_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_mark_message_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/mark-message', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_read_all_message_post(self, **kwargs):  # noqa: E501
        """用户全部消息一键已读 read all message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_read_all_message_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateUserMsgStatus update_user_msg_status:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_read_all_message_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_message_type_read_all_message_post_with_http_info(self, **kwargs):  # noqa: E501
        """用户全部消息一键已读 read all message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_read_all_message_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateUserMsgStatus update_user_msg_status:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_user_msg_status'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_read_all_message_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_user_msg_status' in local_var_params:
            body_params = local_var_params['update_user_msg_status']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/read-all-message', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_read_message_post(self, **kwargs):  # noqa: E501
        """指定消息为已读 read message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_read_message_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_read_message_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_message_type_read_message_post_with_http_info(self, **kwargs):  # noqa: E501
        """指定消息为已读 read message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_read_message_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_read_message_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/read-message', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_message_type_send_message_post(self, **kwargs):  # noqa: E501
        """发送消息 send message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_send_message_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddUserMsg] add_user_msg:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_message_type_send_message_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_message_type_send_message_post_with_http_info(self, **kwargs):  # noqa: E501
        """发送消息 send message  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_message_type_send_message_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddUserMsg] add_user_msg:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_user_msg'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_message_type_send_message_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_user_msg' in local_var_params:
            body_params = local_var_params['add_user_msg']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/message-type/send-message', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_result_analysis_service.api_client import ApiClient
from dhicn_result_analysis_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class M2DApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_result2d_by_range_time_post(self, **kwargs):  # noqa: E501
        """获取时间段内的二维动态结果 Get 2D dynamic results for a specified time range  # noqa: E501

        获取特定时间段内的二维动态结果，其中ElementIds用于进一步过滤结果，单次查询不能超过1000个网格，以减少单次访问返回的数据量 Get 2D dynamic results for a specified time range, and ElementIds must be used to filter the result to no more than 1000 elements, thus reduce the data amount returned one time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_by_range_time_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param M2DByRangeTimeInput m2_d_by_range_time_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseDynamicOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result2d_by_range_time_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_result2d_by_range_time_post_with_http_info(self, **kwargs):  # noqa: E501
        """获取时间段内的二维动态结果 Get 2D dynamic results for a specified time range  # noqa: E501

        获取特定时间段内的二维动态结果，其中ElementIds用于进一步过滤结果，单次查询不能超过1000个网格，以减少单次访问返回的数据量 Get 2D dynamic results for a specified time range, and ElementIds must be used to filter the result to no more than 1000 elements, thus reduce the data amount returned one time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_by_range_time_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param M2DByRangeTimeInput m2_d_by_range_time_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseDynamicOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'm2_d_by_range_time_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result2d_by_range_time_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'm2_d_by_range_time_input' in local_var_params:
            body_params = local_var_params['m2_d_by_range_time_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/2d/by-range-time', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseDynamicOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result2d_by_range_time_with_elements_post(self, **kwargs):  # noqa: E501
        """获取时间段内的二维动态结果 Get 2D dynamic results for a specified time range  # noqa: E501

        获取特定时间段内的二维动态结果，其中ElementIds用于进一步过滤结果，单次查询不能超过1000个网格，以减少单次访问返回的数据量 Get 2D dynamic results for a specified time range, and ElementIds must be used to filter the result to no more than 1000 elements, thus reduce the data amount returned one time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_by_range_time_with_elements_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param M2DByRangeTimeInput m2_d_by_range_time_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseDynamicOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result2d_by_range_time_with_elements_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_result2d_by_range_time_with_elements_post_with_http_info(self, **kwargs):  # noqa: E501
        """获取时间段内的二维动态结果 Get 2D dynamic results for a specified time range  # noqa: E501

        获取特定时间段内的二维动态结果，其中ElementIds用于进一步过滤结果，单次查询不能超过1000个网格，以减少单次访问返回的数据量 Get 2D dynamic results for a specified time range, and ElementIds must be used to filter the result to no more than 1000 elements, thus reduce the data amount returned one time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_by_range_time_with_elements_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param M2DByRangeTimeInput m2_d_by_range_time_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseDynamicOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'm2_d_by_range_time_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result2d_by_range_time_with_elements_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'm2_d_by_range_time_input' in local_var_params:
            body_params = local_var_params['m2_d_by_range_time_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/2d/by-range-time-with-elements', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseDynamicOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result2d_by_time_get(self, time, scenario_id, **kwargs):  # noqa: E501
        """获取单个时刻的二维动态结果 Get 2D dynamic results of a single time step  # noqa: E501

        获取单个时刻的二维动态结果，其中ElementIds可用于进一步过滤结果以减少单次访问返回的数据量 Get 2D dynamic results of a single time step, meanwhile element ids can be used to filter the result and reduce the data amount returned one time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_by_time_get(time, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str time: 结果查询的时刻 time used to get result (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] element_ids: 搜索的网格编号列表 search element ids or grid ids
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseDynamicOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result2d_by_time_get_with_http_info(time, scenario_id, **kwargs)  # noqa: E501

    def api_v1_result2d_by_time_get_with_http_info(self, time, scenario_id, **kwargs):  # noqa: E501
        """获取单个时刻的二维动态结果 Get 2D dynamic results of a single time step  # noqa: E501

        获取单个时刻的二维动态结果，其中ElementIds可用于进一步过滤结果以减少单次访问返回的数据量 Get 2D dynamic results of a single time step, meanwhile element ids can be used to filter the result and reduce the data amount returned one time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_by_time_get_with_http_info(time, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str time: 结果查询的时刻 time used to get result (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] element_ids: 搜索的网格编号列表 search element ids or grid ids
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseDynamicOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'time',
            'scenario_id',
            'element_ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result2d_by_time_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'time' is set
        if self.api_client.client_side_validation and ('time' not in local_var_params or  # noqa: E501
                                                        local_var_params['time'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `time` when calling `api_v1_result2d_by_time_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result2d_by_time_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'time' in local_var_params and local_var_params['time'] is not None:  # noqa: E501
            query_params.append(('Time', local_var_params['time']))  # noqa: E501
        if 'element_ids' in local_var_params and local_var_params['element_ids'] is not None:  # noqa: E501
            query_params.append(('ElementIds', local_var_params['element_ids']))  # noqa: E501
            collection_formats['ElementIds'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/2d/by-time', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseDynamicOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result2d_by_time_stream_get(self, time, scenario_id, **kwargs):  # noqa: E501
        """获取单个时刻的二维动态结果 Get 2D dynamic results of a single time step  # noqa: E501

        获取单个时刻的二维动态结果，其中ElementIds可用于进一步过滤结果以减少单次访问返回的数据量，结果以文件流的形式返回 Get 2D dynamic results of a single time step, meanwhile element ids can be used to filter the result and reduce the data amount returned one time. Result will be returned as file stream.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_by_time_stream_get(time, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str time: 结果查询的时刻 time used to get result (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] element_ids: 搜索的网格编号列表 search element ids or grid ids
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result2d_by_time_stream_get_with_http_info(time, scenario_id, **kwargs)  # noqa: E501

    def api_v1_result2d_by_time_stream_get_with_http_info(self, time, scenario_id, **kwargs):  # noqa: E501
        """获取单个时刻的二维动态结果 Get 2D dynamic results of a single time step  # noqa: E501

        获取单个时刻的二维动态结果，其中ElementIds可用于进一步过滤结果以减少单次访问返回的数据量，结果以文件流的形式返回 Get 2D dynamic results of a single time step, meanwhile element ids can be used to filter the result and reduce the data amount returned one time. Result will be returned as file stream.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_by_time_stream_get_with_http_info(time, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str time: 结果查询的时刻 time used to get result (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] element_ids: 搜索的网格编号列表 search element ids or grid ids
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'time',
            'scenario_id',
            'element_ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result2d_by_time_stream_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'time' is set
        if self.api_client.client_side_validation and ('time' not in local_var_params or  # noqa: E501
                                                        local_var_params['time'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `time` when calling `api_v1_result2d_by_time_stream_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result2d_by_time_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'time' in local_var_params and local_var_params['time'] is not None:  # noqa: E501
            query_params.append(('Time', local_var_params['time']))  # noqa: E501
        if 'element_ids' in local_var_params and local_var_params['element_ids'] is not None:  # noqa: E501
            query_params.append(('ElementIds', local_var_params['element_ids']))  # noqa: E501
            collection_formats['ElementIds'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/2d/by-time/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result2d_dynamic_get(self, m2_d_data_type, frequency, start_time, end_time, scenario_id, **kwargs):  # noqa: E501
        """获取二维动态结果 Get 2D dynamic results  # noqa: E501

        已弃用，可使用by-time或by-range-time来替代 Use by-time or by-range-time instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_dynamic_get(m2_d_data_type, frequency, start_time, end_time, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str m2_d_data_type: 二维结果类型 2D result type:  0-WaterDepth (required)
        :param int frequency: 查询结果的时间频率 time frequency used to get result (required)
        :param str start_time: 查询结果的开始时间 start time used to get result (required)
        :param str end_time: 查询结果的结束时间 end time used to get result (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] element_ids: 搜索的网格编号列表 search element ids or grid ids
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseDynamicOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result2d_dynamic_get_with_http_info(m2_d_data_type, frequency, start_time, end_time, scenario_id, **kwargs)  # noqa: E501

    def api_v1_result2d_dynamic_get_with_http_info(self, m2_d_data_type, frequency, start_time, end_time, scenario_id, **kwargs):  # noqa: E501
        """获取二维动态结果 Get 2D dynamic results  # noqa: E501

        已弃用，可使用by-time或by-range-time来替代 Use by-time or by-range-time instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_dynamic_get_with_http_info(m2_d_data_type, frequency, start_time, end_time, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str m2_d_data_type: 二维结果类型 2D result type:  0-WaterDepth (required)
        :param int frequency: 查询结果的时间频率 time frequency used to get result (required)
        :param str start_time: 查询结果的开始时间 start time used to get result (required)
        :param str end_time: 查询结果的结束时间 end time used to get result (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] element_ids: 搜索的网格编号列表 search element ids or grid ids
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseDynamicOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'm2_d_data_type',
            'frequency',
            'start_time',
            'end_time',
            'scenario_id',
            'element_ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result2d_dynamic_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'm2_d_data_type' is set
        if self.api_client.client_side_validation and ('m2_d_data_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['m2_d_data_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `m2_d_data_type` when calling `api_v1_result2d_dynamic_get`")  # noqa: E501
        # verify the required parameter 'frequency' is set
        if self.api_client.client_side_validation and ('frequency' not in local_var_params or  # noqa: E501
                                                        local_var_params['frequency'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `frequency` when calling `api_v1_result2d_dynamic_get`")  # noqa: E501
        # verify the required parameter 'start_time' is set
        if self.api_client.client_side_validation and ('start_time' not in local_var_params or  # noqa: E501
                                                        local_var_params['start_time'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `start_time` when calling `api_v1_result2d_dynamic_get`")  # noqa: E501
        # verify the required parameter 'end_time' is set
        if self.api_client.client_side_validation and ('end_time' not in local_var_params or  # noqa: E501
                                                        local_var_params['end_time'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `end_time` when calling `api_v1_result2d_dynamic_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result2d_dynamic_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'm2_d_data_type' in local_var_params and local_var_params['m2_d_data_type'] is not None:  # noqa: E501
            query_params.append(('M2DDataType', local_var_params['m2_d_data_type']))  # noqa: E501
        if 'frequency' in local_var_params and local_var_params['frequency'] is not None:  # noqa: E501
            query_params.append(('Frequency', local_var_params['frequency']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501
        if 'element_ids' in local_var_params and local_var_params['element_ids'] is not None:  # noqa: E501
            query_params.append(('ElementIds', local_var_params['element_ids']))  # noqa: E501
            collection_formats['ElementIds'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/2d/dynamic', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseDynamicOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result2d_muids_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取有积水的二维网格的ID列表 Get 2d result model feature ids  # noqa: E501

        获取所有有出现积水的网格ID列表（三角网格dfsu文件返回的是elementid，正交网格dfs2文件返回的是j,k）Get all element ids(for dfsu) or grid ids (for dfs2,format:j,k), water depth of which are above 0  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_muids_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result2d_muids_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result2d_muids_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取有积水的二维网格的ID列表 Get 2d result model feature ids  # noqa: E501

        获取所有有出现积水的网格ID列表（三角网格dfsu文件返回的是elementid，正交网格dfs2文件返回的是j,k）Get all element ids(for dfsu) or grid ids (for dfs2,format:j,k), water depth of which are above 0  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_muids_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[str], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result2d_muids_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result2d_muids_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/2d/muids', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result2d_static_stream_get(self, m2_d_statistic_type, scenario_id, **kwargs):  # noqa: E501
        """获取二维统计结果 Get 2D statistic results  # noqa: E501

        获取二维网格上的统计结果，包括最大积水深度（单位：米）、积水历时（单位：小时）、最大内涝风险等，结果以文件流的形式返回 Get 2D statistic results including max water depth (unit: m), waterlogging duration (unit: hour), max flood risk, of a flood scenario, return statistic value for each grid. Result will be returned as file stream.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_static_stream_get(m2_d_statistic_type, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str m2_d_statistic_type: 二维统计结果类型 2D statistic type:  0-MaxWaterDepth;  1-FloodDuration;  2-FloodRisk; (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result2d_static_stream_get_with_http_info(m2_d_statistic_type, scenario_id, **kwargs)  # noqa: E501

    def api_v1_result2d_static_stream_get_with_http_info(self, m2_d_statistic_type, scenario_id, **kwargs):  # noqa: E501
        """获取二维统计结果 Get 2D statistic results  # noqa: E501

        获取二维网格上的统计结果，包括最大积水深度（单位：米）、积水历时（单位：小时）、最大内涝风险等，结果以文件流的形式返回 Get 2D statistic results including max water depth (unit: m), waterlogging duration (unit: hour), max flood risk, of a flood scenario, return statistic value for each grid. Result will be returned as file stream.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_static_stream_get_with_http_info(m2_d_statistic_type, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str m2_d_statistic_type: 二维统计结果类型 2D statistic type:  0-MaxWaterDepth;  1-FloodDuration;  2-FloodRisk; (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'm2_d_statistic_type',
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result2d_static_stream_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'm2_d_statistic_type' is set
        if self.api_client.client_side_validation and ('m2_d_statistic_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['m2_d_statistic_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `m2_d_statistic_type` when calling `api_v1_result2d_static_stream_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result2d_static_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'm2_d_statistic_type' in local_var_params and local_var_params['m2_d_statistic_type'] is not None:  # noqa: E501
            query_params.append(('M2DStatisticType', local_var_params['m2_d_statistic_type']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/2d/static/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result2d_timeseries_get(self, m2_d_data_type, element_id, scenario_id, **kwargs):  # noqa: E501
        """获取单个网格的时间序列结果 Get time series result on a single cell  # noqa: E501

        获取单个网格上的水深时间序列结果数据 Get water depth time series result on a single mesh cell of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_timeseries_get(m2_d_data_type, element_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str m2_d_data_type: 二维结果类型 2D result type:  0-WaterDepth (required)
        :param str element_id: 网格编号 element id or grid id (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseTimeseriesOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result2d_timeseries_get_with_http_info(m2_d_data_type, element_id, scenario_id, **kwargs)  # noqa: E501

    def api_v1_result2d_timeseries_get_with_http_info(self, m2_d_data_type, element_id, scenario_id, **kwargs):  # noqa: E501
        """获取单个网格的时间序列结果 Get time series result on a single cell  # noqa: E501

        获取单个网格上的水深时间序列结果数据 Get water depth time series result on a single mesh cell of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result2d_timeseries_get_with_http_info(m2_d_data_type, element_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str m2_d_data_type: 二维结果类型 2D result type:  0-WaterDepth (required)
        :param str element_id: 网格编号 element id or grid id (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseTimeseriesOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'm2_d_data_type',
            'element_id',
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result2d_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'm2_d_data_type' is set
        if self.api_client.client_side_validation and ('m2_d_data_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['m2_d_data_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `m2_d_data_type` when calling `api_v1_result2d_timeseries_get`")  # noqa: E501
        # verify the required parameter 'element_id' is set
        if self.api_client.client_side_validation and ('element_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['element_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `element_id` when calling `api_v1_result2d_timeseries_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result2d_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'm2_d_data_type' in local_var_params and local_var_params['m2_d_data_type'] is not None:  # noqa: E501
            query_params.append(('M2DDataType', local_var_params['m2_d_data_type']))  # noqa: E501
        if 'element_id' in local_var_params and local_var_params['element_id'] is not None:  # noqa: E501
            query_params.append(('ElementID', local_var_params['element_id']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/2d/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseTimeseriesOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    scenario-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_scenario_manager_service.configuration import Configuration


class AddLibrariesPara(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenariogroup': 'str',
        'name': 'str',
        'type': 'int',
        'business_type': 'int',
        'readonly': 'int',
        'bind_template': 'int',
        'bind_type': 'int',
        'bind_business_type': 'int',
        'enable_multi_template': 'int',
        'description': 'str'
    }

    attribute_map = {
        'scenariogroup': 'scenariogroup',
        'name': 'name',
        'type': 'type',
        'business_type': 'businessType',
        'readonly': 'readonly',
        'bind_template': 'bindTemplate',
        'bind_type': 'bindType',
        'bind_business_type': 'bindBusinessType',
        'enable_multi_template': 'enableMultiTemplate',
        'description': 'description'
    }

    def __init__(self, scenariogroup=None, name=None, type=None, business_type=None, readonly=None, bind_template=None, bind_type=None, bind_business_type=None, enable_multi_template=None, description=None, local_vars_configuration=None):  # noqa: E501
        """AddLibrariesPara - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenariogroup = None
        self._name = None
        self._type = None
        self._business_type = None
        self._readonly = None
        self._bind_template = None
        self._bind_type = None
        self._bind_business_type = None
        self._enable_multi_template = None
        self._description = None
        self.discriminator = None

        if scenariogroup is not None:
            self.scenariogroup = scenariogroup
        self.name = name
        if type is not None:
            self.type = type
        if business_type is not None:
            self.business_type = business_type
        if readonly is not None:
            self.readonly = readonly
        if bind_template is not None:
            self.bind_template = bind_template
        if bind_type is not None:
            self.bind_type = bind_type
        if bind_business_type is not None:
            self.bind_business_type = bind_business_type
        self.enable_multi_template = enable_multi_template
        self.description = description

    @property
    def scenariogroup(self):
        """Gets the scenariogroup of this AddLibrariesPara.  # noqa: E501

        方案组ID scenario group's Id  # noqa: E501

        :return: The scenariogroup of this AddLibrariesPara.  # noqa: E501
        :rtype: str
        """
        return self._scenariogroup

    @scenariogroup.setter
    def scenariogroup(self, scenariogroup):
        """Sets the scenariogroup of this AddLibrariesPara.

        方案组ID scenario group's Id  # noqa: E501

        :param scenariogroup: The scenariogroup of this AddLibrariesPara.  # noqa: E501
        :type: str
        """

        self._scenariogroup = scenariogroup

    @property
    def name(self):
        """Gets the name of this AddLibrariesPara.  # noqa: E501

        库的名称 library name  # noqa: E501

        :return: The name of this AddLibrariesPara.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddLibrariesPara.

        库的名称 library name  # noqa: E501

        :param name: The name of this AddLibrariesPara.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this AddLibrariesPara.  # noqa: E501

        库的类型 library type:  0-Undefined  1-AutoForecast  2-ManualForecast  3-Forecast  4-Schedule  5-Experience  6-ScenarioSimulation  7-WQAccident  8-OnlineHD  9-WaterHammer  10-Filling  11-PipeBurst  12-WQResponse  13-Planning  14-Flushing  15-OnlineWQAccident  16-CloseValve  17-WWTP  18-WWTPOptim  19-WWTPMLab  # noqa: E501

        :return: The type of this AddLibrariesPara.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AddLibrariesPara.

        库的类型 library type:  0-Undefined  1-AutoForecast  2-ManualForecast  3-Forecast  4-Schedule  5-Experience  6-ScenarioSimulation  7-WQAccident  8-OnlineHD  9-WaterHammer  10-Filling  11-PipeBurst  12-WQResponse  13-Planning  14-Flushing  15-OnlineWQAccident  16-CloseValve  17-WWTP  18-WWTPOptim  19-WWTPMLab  # noqa: E501

        :param type: The type of this AddLibrariesPara.  # noqa: E501
        :type: int
        """

        self._type = type

    @property
    def business_type(self):
        """Gets the business_type of this AddLibrariesPara.  # noqa: E501

        库的业务类型 business type:  0-Undefined  1-WaterEnvironmnet  2-UrbanFlooding  3-WaterDistribution  4-RiverFlood  5-WWTP  # noqa: E501

        :return: The business_type of this AddLibrariesPara.  # noqa: E501
        :rtype: int
        """
        return self._business_type

    @business_type.setter
    def business_type(self, business_type):
        """Sets the business_type of this AddLibrariesPara.

        库的业务类型 business type:  0-Undefined  1-WaterEnvironmnet  2-UrbanFlooding  3-WaterDistribution  4-RiverFlood  5-WWTP  # noqa: E501

        :param business_type: The business_type of this AddLibrariesPara.  # noqa: E501
        :type: int
        """

        self._business_type = business_type

    @property
    def readonly(self):
        """Gets the readonly of this AddLibrariesPara.  # noqa: E501

        0代表可读写，1代表只读 0 for not readonly, 1 for readonly  # noqa: E501

        :return: The readonly of this AddLibrariesPara.  # noqa: E501
        :rtype: int
        """
        return self._readonly

    @readonly.setter
    def readonly(self, readonly):
        """Sets the readonly of this AddLibrariesPara.

        0代表可读写，1代表只读 0 for not readonly, 1 for readonly  # noqa: E501

        :param readonly: The readonly of this AddLibrariesPara.  # noqa: E501
        :type: int
        """

        self._readonly = readonly

    @property
    def bind_template(self):
        """Gets the bind_template of this AddLibrariesPara.  # noqa: E501

        1表示库直接绑定一个模板方案，0表示不绑定 1 for bind a template directly, 0 for not  # noqa: E501

        :return: The bind_template of this AddLibrariesPara.  # noqa: E501
        :rtype: int
        """
        return self._bind_template

    @bind_template.setter
    def bind_template(self, bind_template):
        """Sets the bind_template of this AddLibrariesPara.

        1表示库直接绑定一个模板方案，0表示不绑定 1 for bind a template directly, 0 for not  # noqa: E501

        :param bind_template: The bind_template of this AddLibrariesPara.  # noqa: E501
        :type: int
        """

        self._bind_template = bind_template

    @property
    def bind_type(self):
        """Gets the bind_type of this AddLibrariesPara.  # noqa: E501

        当BindTemplate为0，此项表示其绑定的库的类型 Bind library type for a template, in case of BindTemplate is 0:  0-Undefined  1-AutoForecast  2-ManualForecast  3-Forecast  4-Schedule  5-Experience  6-ScenarioSimulation  7-WQAccident  8-OnlineHD  9-WaterHammer  10-Filling  11-PipeBurst  12-WQResponse  13-Planning  14-Flushing  15-OnlineWQAccident  16-CloseValve  17-WWTP  18-WWTPOptim  19-WWTPMLab  # noqa: E501

        :return: The bind_type of this AddLibrariesPara.  # noqa: E501
        :rtype: int
        """
        return self._bind_type

    @bind_type.setter
    def bind_type(self, bind_type):
        """Sets the bind_type of this AddLibrariesPara.

        当BindTemplate为0，此项表示其绑定的库的类型 Bind library type for a template, in case of BindTemplate is 0:  0-Undefined  1-AutoForecast  2-ManualForecast  3-Forecast  4-Schedule  5-Experience  6-ScenarioSimulation  7-WQAccident  8-OnlineHD  9-WaterHammer  10-Filling  11-PipeBurst  12-WQResponse  13-Planning  14-Flushing  15-OnlineWQAccident  16-CloseValve  17-WWTP  18-WWTPOptim  19-WWTPMLab  # noqa: E501

        :param bind_type: The bind_type of this AddLibrariesPara.  # noqa: E501
        :type: int
        """

        self._bind_type = bind_type

    @property
    def bind_business_type(self):
        """Gets the bind_business_type of this AddLibrariesPara.  # noqa: E501

        当BindTemplate为0，此项表示其绑定的库的业务类型 Bind business type for a template, in case of BindTemplate is 0:  0-Undefined  1-WaterEnvironmnet  2-UrbanFlooding  3-WaterDistribution  4-RiverFlood  5-WWTP  # noqa: E501

        :return: The bind_business_type of this AddLibrariesPara.  # noqa: E501
        :rtype: int
        """
        return self._bind_business_type

    @bind_business_type.setter
    def bind_business_type(self, bind_business_type):
        """Sets the bind_business_type of this AddLibrariesPara.

        当BindTemplate为0，此项表示其绑定的库的业务类型 Bind business type for a template, in case of BindTemplate is 0:  0-Undefined  1-WaterEnvironmnet  2-UrbanFlooding  3-WaterDistribution  4-RiverFlood  5-WWTP  # noqa: E501

        :param bind_business_type: The bind_business_type of this AddLibrariesPara.  # noqa: E501
        :type: int
        """

        self._bind_business_type = bind_business_type

    @property
    def enable_multi_template(self):
        """Gets the enable_multi_template of this AddLibrariesPara.  # noqa: E501

        0表示只能绑定单个模板方案，1表示可以绑定多个模板方案 0 for single template which is the default option, 1 for multiple templates  # noqa: E501

        :return: The enable_multi_template of this AddLibrariesPara.  # noqa: E501
        :rtype: int
        """
        return self._enable_multi_template

    @enable_multi_template.setter
    def enable_multi_template(self, enable_multi_template):
        """Sets the enable_multi_template of this AddLibrariesPara.

        0表示只能绑定单个模板方案，1表示可以绑定多个模板方案 0 for single template which is the default option, 1 for multiple templates  # noqa: E501

        :param enable_multi_template: The enable_multi_template of this AddLibrariesPara.  # noqa: E501
        :type: int
        """

        self._enable_multi_template = enable_multi_template

    @property
    def description(self):
        """Gets the description of this AddLibrariesPara.  # noqa: E501

        库的描述 description  # noqa: E501

        :return: The description of this AddLibrariesPara.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddLibrariesPara.

        库的描述 description  # noqa: E501

        :param description: The description of this AddLibrariesPara.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddLibrariesPara):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddLibrariesPara):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_scenario_compute_service.api.config_api import ConfigApi
from dhicn_scenario_compute_service.api.dapr_api import DaprApi
from dhicn_scenario_compute_service.api.rf_scenario_api import RFScenarioApi
from dhicn_scenario_compute_service.api.scenario_api import ScenarioApi
from dhicn_scenario_compute_service.api.scenario_process_api import ScenarioProcessApi
from dhicn_scenario_compute_service.api.task_schedule_api import TaskScheduleApi
from dhicn_scenario_compute_service.api.task_schedule_ope_api import TaskScheduleOpeApi
from dhicn_scenario_compute_service.api.wd_scenario_api import WDScenarioApi



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class WqEventDetailInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'event_type': 'int',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'location': 'str',
        'discharge_value': 'Null',
        'components': 'list[WdComponentDetailInput]'
    }

    attribute_map = {
        'event_type': 'eventType',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'location': 'location',
        'discharge_value': 'dischargeValue',
        'components': 'components'
    }

    def __init__(self, event_type=None, start_time=None, end_time=None, location=None, discharge_value=None, components=None, local_vars_configuration=None):  # noqa: E501
        """WqEventDetailInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._event_type = None
        self._start_time = None
        self._end_time = None
        self._location = None
        self._discharge_value = None
        self._components = None
        self.discriminator = None

        if event_type is not None:
            self.event_type = event_type
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        self.location = location
        if discharge_value is not None:
            self.discharge_value = discharge_value
        self.components = components

    @property
    def event_type(self):
        """Gets the event_type of this WqEventDetailInput.  # noqa: E501

        0-PipeBurst(爆管) 1-CloseValve(关阀) 2-WQAccident(水质事件)   # noqa: E501

        :return: The event_type of this WqEventDetailInput.  # noqa: E501
        :rtype: int
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this WqEventDetailInput.

        0-PipeBurst(爆管) 1-CloseValve(关阀) 2-WQAccident(水质事件)   # noqa: E501

        :param event_type: The event_type of this WqEventDetailInput.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_type` ({0}), must be one of {1}"  # noqa: E501
                .format(event_type, allowed_values)
            )

        self._event_type = event_type

    @property
    def start_time(self):
        """Gets the start_time of this WqEventDetailInput.  # noqa: E501

        开始时间  # noqa: E501

        :return: The start_time of this WqEventDetailInput.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this WqEventDetailInput.

        开始时间  # noqa: E501

        :param start_time: The start_time of this WqEventDetailInput.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this WqEventDetailInput.  # noqa: E501

        结束时间  # noqa: E501

        :return: The end_time of this WqEventDetailInput.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this WqEventDetailInput.

        结束时间  # noqa: E501

        :param end_time: The end_time of this WqEventDetailInput.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def location(self):
        """Gets the location of this WqEventDetailInput.  # noqa: E501

        事件位置，对于爆管事件和水质事件，填模型id  # noqa: E501

        :return: The location of this WqEventDetailInput.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this WqEventDetailInput.

        事件位置，对于爆管事件和水质事件，填模型id  # noqa: E501

        :param location: The location of this WqEventDetailInput.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def discharge_value(self):
        """Gets the discharge_value of this WqEventDetailInput.  # noqa: E501

        排水量/泄水量  # noqa: E501

        :return: The discharge_value of this WqEventDetailInput.  # noqa: E501
        :rtype: Null
        """
        return self._discharge_value

    @discharge_value.setter
    def discharge_value(self, discharge_value):
        """Sets the discharge_value of this WqEventDetailInput.

        排水量/泄水量  # noqa: E501

        :param discharge_value: The discharge_value of this WqEventDetailInput.  # noqa: E501
        :type: Null
        """

        self._discharge_value = discharge_value

    @property
    def components(self):
        """Gets the components of this WqEventDetailInput.  # noqa: E501

        污染物(水质事件使用)  # noqa: E501

        :return: The components of this WqEventDetailInput.  # noqa: E501
        :rtype: list[WdComponentDetailInput]
        """
        return self._components

    @components.setter
    def components(self, components):
        """Sets the components of this WqEventDetailInput.

        污染物(水质事件使用)  # noqa: E501

        :param components: The components of this WqEventDetailInput.  # noqa: E501
        :type: list[WdComponentDetailInput]
        """

        self._components = components

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WqEventDetailInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WqEventDetailInput):
            return True

        return self.to_dict() != other.to_dict()
